| autocodebook-package | R Documentation |
Wraps dplyr verbs to automatically capture variable metadata (type, source columns, categories, and source code), producing a codebook and an eligibility tracking table with zero manual documentation.
Maintainer: Patricia Fortes C. de Macedo macedopatriciafortes@gmail.com
Authors:
Patricia Fortes C. de Macedo macedopatriciafortes@gmail.com
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.